@@ -38,6 +38,9 @@ FAILEDOPERATION_COPYRIGHTERROR = 'FailedOperation.CopyRightError'
 # Failed to create the flow.
 FAILEDOPERATION_CREATEFLOWFAILED = 'FailedOperation.CreateFlowFailed'
 
+# Failed to create an order.
+FAILEDOPERATION_CREATEORDERFAILED = 'FailedOperation.CreateOrderFailed'
+
 # Failed to create the account.
 FAILEDOPERATION_CREATEUSERFAILED = 'FailedOperation.CreateUserFailed'
 
@@ -59,6 +62,9 @@ FAILEDOPERATION_RESETPASSWORDFAILED = 'FailedOperation.ResetPasswordFailed'
 # Failed to set a rule.
 FAILEDOPERATION_SETRULELOCATIONFAILED = 'FailedOperation.SetRuleLocationFailed'
 
+# Either tag key/value verification or tag API authentication failed.
+FAILEDOPERATION_TAGDRYRUNERROR = 'FailedOperation.TagDryRunError'
+
 # Failed to update the security group information of an instance.
 FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFailed'
 
@@ -86,6 +92,9 @@ INTERNALERROR_DBOPERATIONFAILED = 'InternalError.DbOperationFailed'
 # Failed to query the information of a dedicated cluster.
 INTERNALERROR_FENCEERROR = 'InternalError.FenceError'
 
+# Failed to get the monitoring metric data.
+INTERNALERROR_FETCHMETRICDATAFAILED = 'InternalError.FetchMetricDataFailed'
+
 # Failed to get database instance parameters.
 INTERNALERROR_GETDBCONFIGFAILED = 'InternalError.GetDbConfigFailed'
 
@@ -107,6 +116,9 @@ INTERNALERROR_GETSECURITYGROUPDETAILFAILED = 'InternalError.GetSecurityGroupDeta
 # Failed to get the error log.
 INTERNALERROR_GETSLOWLOGFAILED = 'InternalError.GetSlowLogFailed'
 
+# Failed to query the VPC subnet information.
+INTERNALERROR_GETSUBNETFAILED = 'InternalError.GetSubnetFailed'
+
 # Failed to get the account list.
 INTERNALERROR_GETUSERLISTFAILED = 'InternalError.GetUserListFailed'
 
@@ -170,6 +182,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # The password contains invalid characters.
 INVALIDPARAMETER_CHARACTERERROR = 'InvalidParameter.CharacterError'
 
+# Parameter check failed.
+INVALIDPARAMETER_CHECKPARAMNOTPASS = 'InvalidParameter.CheckParamNotPass'
+
 # The specified flow information was not found.
 INVALIDPARAMETER_FLOWNOTFOUND = 'InvalidParameter.FlowNotFound'
 
@@ -197,6 +212,12 @@ INVALIDPARAMETER_SHARDRESOURCEIDNOTFOUND = 'InvalidParameter.ShardResourceIdNotF
 # The specified VPC subnet was not found.
 INVALIDPARAMETER_SUBNETNOTFOUND = 'InvalidParameter.SubnetNotFound'
 
+# The specified VPC subnet was not found.
+INVALIDPARAMETER_VPCNOTFOUND = 'InvalidParameter.VpcNotFound'
+
+# Incorrect AZ information.
+INVALIDPARAMETER_ZONEIDILLEGAL = 'InvalidParameter.ZoneIdIllegal'
+
 # The account to be created already exists.
 INVALIDPARAMETERVALUE_ACCOUNTALREADYEXISTS = 'InvalidParameterValue.AccountAlreadyExists'
 
@@ -218,9 +239,15 @@ INVALIDPARAMETERVALUE_ILLEGALINITPARAM = 'InvalidParameterValue.IllegalInitParam
 # The number of days for log retention after modification is either too high or too low.
 INVALIDPARAMETERVALUE_ILLEGALLOGSAVEDAYS = 'InvalidParameterValue.IllegalLogSaveDays'
 
+# The number of products exceeds the upper limit.
+INVALIDPARAMETERVALUE_ILLEGALQUANTITY = 'InvalidParameterValue.IllegalQuantity'
+
 # Incorrect permission parameters
 INVALIDPARAMETERVALUE_ILLEGALRIGHTPARAM = 'InvalidParameterValue.IllegalRightParam'
 
+# Information of the specified AZ was not found.
+INVALIDPARAMETERVALUE_ILLEGALZONE = 'InvalidParameterValue.IllegalZone'
+
 # Invalid instance name.
 INVALIDPARAMETERVALUE_INSTANCENAMEILLEGAL = 'InvalidParameterValue.InstanceNameIllegal'
 
